Gallery
-------

.. raw:: html

  <div class="gallery">

  <a class="gallery" href="https://github.com/pylbm/pylbm_gallery/blob/master/Karman_vortex_street/Re%3D250/Karman_vortex_street.py">
  <figure>
  <video control autoplay loop="loop" alt="Suni">
    <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/Karman_vortex_street/Re%3D250/Karman_vortex_street.mp4" type="video/mp4">
    <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/Karman_vortex_street/Re%3D250/Karman_vortex_street.ogv" type="video/ogv">
    Your browser does not support the video tag.
  </video>
  </figure>
  <span>Vortex street (Re = 250)</span>
  </a>

  <a class="gallery" href="https://github.com/pylbm/pylbm_gallery/blob/master/Karman_vortex_street/Re%3D2500/Karman_vortex_street.py">
  <figure>
  <video control autoplay loop="loop" alt="Suni">
    <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/Karman_vortex_street/Re%3D2500/Karman_vortex_street.mp4" type="video/mp4">
    <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/Karman_vortex_street/Re%3D2500/Karman_vortex_street.ogv" type="video/ogv">
    Your browser does not support the video tag.    
  </video>
  </figure>
  <span>Vortex street (Re = 2500)</span>
  </a>
  
  <a class="gallery" href="https://github.com/pylbm/pylbm_gallery/blob/master/Rayleigh_Benard/Rayleigh-Benard.py">
  <figure>
  <video control autoplay loop="loop" alt="Suni"> 
    <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/Rayleigh_Benard/Rayleigh_Benard.mp4" type="video/mp4">
    <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/Rayleigh_Benard/Rayleigh_Benard.ogv" type="video/ogv">
    Your browser does not support the video tag.
  </video>
  </figure>
  <span>Rayleigh Benard</span>
  </a>
  
  <a class="gallery" href="https://github.com/pylbm/pylbm_gallery/blob/master/shallow_water/shallow_water.py">
  <figure>
  <video control autoplay loop="loop" alt="Suni">
    <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/shallow_water/shallow_water.mp4" type="video/mp4">
    <source src="https://raw.githubusercontent.com/pylbm/pylbm_gallery/master/shallow_water/shallow_water.ogv" type="video/ogv">
    Your browser does not support the video tag.
  </video>
  </figure>
  <span>Shallow water</span>
  </a>

  </div>